meta_package_manager.bitbar.meta_package_manager.7h module
==========================================================

.. automodule:: meta_package_manager.bitbar.meta_package_manager.7h
    :members:
    :undoc-members:
    :show-inheritance:
